@@ -35,6 +35,7 @@ GIRepository.Repository.prepend_search_path('libgd')
 from gi.repository import Gtk, Gdk, GLib, Gio, GObject, Gst, GstAudio, GstPbutils
 from gettext import gettext as _
 from random import randint
+from queue import LifoQueue
 from gnomemusic.albumArtCache import AlbumArtCache
 
 ART_SIZE = 34
@@ -56,6 +57,7 @@ class PlaybackStatus:
 class Player(GObject.GObject):
     nextTrack = None
     timeout = None
+    shuffleHistory = LifoQueue(maxsize=10)
 
     __gsignals__ = {
         'playing-changed': (GObject.SIGNAL_RUN_FIRST, None, ()),
@@ -106,6 +108,7 @@ class Player(GObject.GObject):
     def discover_item(self, item, callback, data=None):
         url = item.get_url()
         if not url:
+            print("The item %s doesn't have a URL set" % item)
             return
 
         obj = (callback, data)
@@ -224,6 +227,9 @@ class Player(GObject.GObject):
         elif self.repeat == RepeatType.SHUFFLE:
             if currentTrack:
                 nextTrack = self._get_random_iter(currentTrack)
+                if self.shuffleHistory.full():
+                    self.shuffleHistory.get_nowait()
+                self.shuffleHistory.put_nowait(currentTrack)
 
         if nextTrack:
             return Gtk.TreeRowReference.new(self.playlist, self.playlist.get_path(nextTrack))
@@ -263,7 +269,10 @@ class Player(GObject.GObject):
                 previousTrack = self.playlist.iter_previous(currentTrack)
         elif self.repeat == RepeatType.SHUFFLE:
             if currentTrack:
-                previousTrack = self._get_random_iter(currentTrack)
+                if not self.shuffleHistory.empty():
+                    previousTrack = self.shuffleHistory.get_nowait()
+                else:
+                    previousTrack = self._get_random_iter(currentTrack)
 
         if previousTrack:
             return Gtk.TreeRowReference.new(self.playlist, self.playlist.get_path(previousTrack))
@@ -375,11 +384,11 @@ class Player(GObject.GObject):
         if self.player.get_state(1)[1] != Gst.State.PAUSED:
             self.stop()
 
-        media = self.get_current_media()
-        if not media:
-            return
+            media = self.get_current_media()
+            if not media:
+                return
 
-        self.load(media)
+            self.load(media)
 
         self.player.set_state(Gst.State.PLAYING)
         self._update_position_callback()
@@ -426,8 +435,12 @@ class Player(GObject.GObject):
         if self.prevBtn.get_sensitive() is False:
             return
 
+        position = self.get_position() / 1000000
+
         self.stop()
-        self.currentTrack = self._get_previous_track()
+
+        if position < 5:
+            self.currentTrack = self._get_previous_track()
 
         if self.currentTrack:
             self.play()
